@@ -1,10 +1,11 @@
 from typing import List
+from typing import TYPE_CHECKING
 
+from .hkObject import hkObject
 from ...binary import BinaryReader, BinaryWriter
 from ...binary.types import UInt8, UInt16, UInt32
-from .hkObject import hkObject
 
-if False:
+if TYPE_CHECKING:
     from ...hkfile import HKFile
     from ...container.util.hkobject import HKObject
 
@@ -20,6 +21,7 @@ class hkpCollidableBoundingVolumeData(hkObject):
 
     numChildShapeAabbs: UInt16
     capacityChildShapeAabbs: UInt16
+
     # childShapeAabbs: None = None
     # childShapeKeys: None = None
 
