@@ -1,19 +1,18 @@
 import argparse
-import json
-import os
-from copy import deepcopy
 
+from colorama import init
+
+from .common import Messages, shapes_to_hkrb, Path
 from .. import Havok
-from .common import Messages, init, shapes_to_hkrb
 
 
 def parse_args():
     parser = argparse.ArgumentParser(
         description="Convert Havok Static Compound (.hksc) to Havok Rigid Body array (.hkrb)"
     )
-    parser.add_argument("hkscFile", help="Path to a Havok Static Compound file")
+    parser.add_argument("hkscFile", type=Path, help="Path to a Havok Static Compound file")
     parser.add_argument(
-        "outFile", help="Path to the destination Havok Rigid Body file", nargs="?"
+        "outFile", type=Path, help="Path to the destination Havok Rigid Body file", nargs="?"
     )
 
     return parser.parse_args()
@@ -35,10 +34,10 @@ def main():
     shapes = [
         instance.shape
         for rigidbody in hk.files[1]
-        .data.contents[0]
-        .namedVariants[0]
-        .variant.systems[0]
-        .rigidBodies
+            .data.contents[0]
+            .namedVariants[0]
+            .variant.systems[0]
+            .rigidBodies
         for instance in rigidbody.collidable.shape.instances
     ]
 
